==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/SplineSeriesBaseDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HorizontalAnchoredCategorySeriesDescription } from "./HorizontalAnchoredCategorySeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var SplineSeriesBaseDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SplineSeriesBaseDescription, _super);
    function SplineSeriesBaseDescription() {
        var _this = _super.call(this) || this;
        _this.er = false;
        _this.et = null;
        return _this;
    }
    SplineSeriesBaseDescription.prototype.get_type = function () {
        return "SplineSeriesBase";
    };
    Object.defineProperty(SplineSeriesBaseDescription.prototype, "isSplineShapePartOfRange", {
        get: function () {
            return this.er;
        },
        set: function (a) {
            this.er = a;
            this.e("IsSplineShapePartOfRange");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SplineSeriesBaseDescription.prototype, "splineType", {
        get: function () {
            return this.et;
        },
        set: function (a) {
            this.et = a;
            this.e("SplineType");
        },
        enumerable: false,
        configurable: true
    });
    SplineSeriesBaseDescription.$t = markType(SplineSeriesBaseDescription, 'SplineSeriesBaseDescription', HorizontalAnchoredCategorySeriesDescription.$);
    return SplineSeriesBaseDescription;
}(HorizontalAnchoredCategorySeriesDescription));
export { SplineSeriesBaseDescription };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/SplineSeriesBaseDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HorizontalAnchoredCategorySeriesDescription } from "./HorizontalAnchoredCategorySeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var SplineSeriesBaseDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SplineSeriesBaseDescription, _super);
    function SplineSeriesBaseDescription() {
        var _this = _super.call(this) || this;
        _this.g1 = false;
        _this.g3 = null;
        return _this;
    }
    SplineSeriesBaseDescription.prototype.get_type = function () {
        return "SplineSeriesBase";
    };
    Object.defineProperty(SplineSeriesBaseDescription.prototype, "isSplineShapePartOfRange", {
        get: function () {
            return this.g1;
        },
        set: function (a) {
            this.g1 = a;
            this.g("IsSplineShapePartOfRange");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SplineSeriesBaseDescription.prototype, "splineType", {
        get: function () {
            return this.g3;
        },
        set: function (a) {
            this.g3 = a;
            this.g("SplineType");
        },
        enumerable: false,
        configurable: true
    });
    SplineSeriesBaseDescription.$t = markType(SplineSeriesBaseDescription, 'SplineSeriesBaseDescription', HorizontalAnchoredCategorySeriesDescription.$);
    return SplineSeriesBaseDescription;
}(HorizontalAnchoredCategorySeriesDescription));
export { SplineSeriesBaseDescription };
